@@ -22,10 +22,12 @@ __all__ = (
     "Literal",
     "List",
     "Listx",
+    "Mapping",
     "Optional",
     "NoneType",
     "Union",
     "Set",
+    "Sequence",
     "Tuple",
     "Tuplex",
     "Type",
